@@ -102,11 +102,11 @@ class GiftCardsApi(BaseApi):
         """Does a POST request to /v2/gift-cards.
 
         Creates a digital gift card or registers a physical (plastic) gift
-        card. You must activate the gift card before 
-        it can be used for payment. For more information, see 
-        [Selling gift
-        cards](https://developer.squareup.com/docs/gift-cards/using-gift-cards-
-        api#selling-square-gift-cards).
+        card. After the gift card 
+        is created, you must call
+        [CreateGiftCardActivity]($e/GiftCardActivities/CreateGiftCardActivity)
+                to activate the card with an initial balance before it can be used for
+        payment.
 
         Args:
             body (CreateGiftCardRequest): An object containing the fields to
@@ -369,7 +369,7 @@ class GiftCardsApi(BaseApi):
                            id):
         """Does a GET request to /v2/gift-cards/{id}.
 
-        Retrieves a gift card using its ID.
+        Retrieves a gift card using the gift card ID.
 
         Args:
             id (string): The ID of the gift card to retrieve.
